.. mdinclude:: ../README.md

Content
-------

.. toctree::
	:maxdepth: 1
	:caption: Pages

	pages/faq.rst
	pages/contributing.rst
	examples/examples.rst

.. toctree::
	:maxdepth: 1
	:caption: API Documentation

	api/basic.rst
	api/motd_parsing.rst
	api/internal.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
